Enum State

#[non_exhaustive]
#[repr(u32)]
pub enum State {
Show 13 variants Maximized = 1, Fullscreen = 2, Resizing = 3, Activated = 4, TiledLeft = 5, TiledRight = 6, TiledTop = 7, TiledBottom = 8, Suspended = 9, ConstrainedLeft = 10, ConstrainedRight = 11, ConstrainedTop = 12, ConstrainedBottom = 13,
}
Available on crate feature wayland and Linux only.
types of state on the surface

The different state values used on the surface. This is designed for state values like maximized, fullscreen. It is paired with the configure event to ensure that both the client and the compositor setting the state can be synchronized.

States set in this way are double-buffered, see wl_surface.commit.

Variants (Non-exhaustive)

This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.


Maximized = 1

the surface is maximized

The surface is maximized. The window geometry specified in the configure event must be obeyed by the client, or the xdg_wm_base.invalid_surface_state error is raised.

The client should draw without shadow or other decoration outside of the window geometry.



Fullscreen = 2

the surface is fullscreen

The surface is fullscreen. The window geometry specified in the configure event is a maximum; the client cannot resize beyond it. For a surface to cover the whole fullscreened area, the geometry dimensions must be obeyed by the client. For more details, see xdg_toplevel.set_fullscreen.



Resizing = 3

the surface is being resized

The surface is being resized. The window geometry specified in the configure event is a maximum; the client cannot resize beyond it. Clients that have aspect ratio or cell sizing configuration can use a smaller size, however.



Activated = 4

the surface is now activated

Client window decorations should be painted as if the window is active. Do not assume this means that the window actually has keyboard or pointer focus.



TiledLeft = 5

the surface’s left edge is tiled

The window is currently in a tiled layout and the left edge is considered to be adjacent to another part of the tiling grid.

The client should draw without shadow or other decoration outside of the window geometry on the left edge.



TiledRight = 6

the surface’s right edge is tiled

The window is currently in a tiled layout and the right edge is considered to be adjacent to another part of the tiling grid.

The client should draw without shadow or other decoration outside of the window geometry on the right edge.



TiledTop = 7

the surface’s top edge is tiled

The window is currently in a tiled layout and the top edge is considered to be adjacent to another part of the tiling grid.

The client should draw without shadow or other decoration outside of the window geometry on the top edge.



TiledBottom = 8

the surface’s bottom edge is tiled

The window is currently in a tiled layout and the bottom edge is considered to be adjacent to another part of the tiling grid.

The client should draw without shadow or other decoration outside of the window geometry on the bottom edge.



Suspended = 9

surface repaint is suspended

The surface is currently not ordinarily being repainted; for example because its content is occluded by another window, or its outputs are switched off due to screen locking.



ConstrainedLeft = 10

the surface’s left edge is constrained

The left edge of the window is currently constrained, meaning it shouldn’t attempt to resize from that edge. It can for example mean it’s tiled next to a monitor edge on the constrained side of the window.



ConstrainedRight = 11

the surface’s right edge is constrained

The right edge of the window is currently constrained, meaning it shouldn’t attempt to resize from that edge. It can for example mean it’s tiled next to a monitor edge on the constrained side of the window.



ConstrainedTop = 12

the surface’s top edge is constrained

The top edge of the window is currently constrained, meaning it shouldn’t attempt to resize from that edge. It can for example mean it’s tiled next to a monitor edge on the constrained side of the window.



ConstrainedBottom = 13

the surface’s bottom edge is constrained

The bottom edge of the window is currently constrained, meaning it shouldn’t attempt to resize from that edge. It can for example mean it’s tiled next to a monitor edge on the constrained side of the window.